function R = raizBesselJ(N,h)
%function R = raizBesselJ(N,h) permite calcular N raices de la funcion de Bessel de orden m, tomando h
%como incremento para ir buscando.
%Los parametros de la funcion ser´an:
%    R: vector con las raices de Bessel
%    N: numero de raixes a obtener
%    h: incremento, para ir avanzando en la busqueda de las raices
%    m: orden de la funcion de Bessel que vamos a trabajar.

a = 0;
b= 0;

for i=1:1:N
    %Voy comprobando hasta encontrar dos extremos del intervalo con signos opuestos
    while sign(Bessel(0,a))*sign(Bessel(0,b))>-1
        b = b+h;
    end    
    %Una vez que tenemos el intervalo en cuestion utilizamos por ejemplo fzero para buscar la raiz
    %Creamos el intervalo de estudio para la funcion
    x=a:h:b;
    R(i) = fzero(inline('BesselJ(0,x)'),[a,b]);
    
    %Una vez almacenada la raiz preparamos el intervalo siguiente de analisis
    
    a=b;
end